summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/assocgenpage.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /umbrello/umbrello/dialogs/assocgenpage.h
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/dialogs/assocgenpage.h')
-rw-r--r--umbrello/umbrello/dialogs/assocgenpage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/assocgenpage.h b/umbrello/umbrello/dialogs/assocgenpage.h
index 06c32c05..6d6ffcdf 100644
--- a/umbrello/umbrello/dialogs/assocgenpage.h
+++ b/umbrello/umbrello/dialogs/assocgenpage.h
@@ -49,10 +49,10 @@ public:
* Sets up the AssocGenPage.
*
* @param d The UMLDoc which controls controls object creation.
* @param tqparent The tqparent to the AssocGenPage.
* @param a The AssociationWidget to display the properties of.
*/
- AssocGenPage(UMLDoc *d, TQWidget *tqparent, AssociationWidget *a);
+ AssocGenPage(UMLDoc *d, TQWidget *parent, AssociationWidget *a);
/**
* Standard deconstructor.
@@ -49,10 +49,10 @@ public:
*
* @param d The UMLDoc which controls controls object creation.
- * @param tqparent The tqparent to the AssocGenPage.
+ * @param parent The parent to the AssocGenPage.
* @param a The AssociationWidget to display the properties of.
*/